<?php 
/**
 * WooCommerce UUID Plugin Functions
 *
 * @author   d.stanisheva
 * @package  woo-uuid
 * @since    1.0.0
 */

	
	function register_printeduuid_order_status() {

	    register_post_status( 'wc-printeduuid', array(
		'label'                     => __('printedUUID', 'woo-uuid'),
		'public'                    => true,
		'exclude_from_search'       => false,
		'show_in_admin_all_list'    => true,
		'show_in_admin_status_list' => true,
		'label_count'               => _n_noop( 'printedUUID <span class="count">(%s)</span>', 'printedUUID <span class="count">(%s)</span>' )
	    ) );
	}
	add_action( 'init', 'register_printeduuid_order_status' );
	
	// Add to list of WC Order statuses
	function add_printeduuid_to_order_statuses( $order_statuses ) {

	    $new_order_statuses = array();
	    // add new order status after processing
	    foreach ( $order_statuses as $key => $status ) {
		$new_order_statuses[ $key ] = $status;
		if ( 'wc-processing' === $key ) {
		    $new_order_statuses['wc-printeduuid'] = 'printedUUID';
		}
	    }
	    return $new_order_statuses;
	}

	add_filter( 'wc_order_statuses', 'add_printeduuid_to_order_statuses' );

	add_action('admin_head', 'styling_admin_printuuid_order_list' );
	function styling_admin_printuuid_order_list() {
	    global $pagenow, $post;

	    if( $pagenow != 'edit.php') return; // Exit
	    if( get_post_type($post->ID) != 'shop_order' ) return; // Exit

	    
	    $order_status = 'printeduuid'; 
	    ?>
	    <style>
		.order-status.status-<?php echo sanitize_title( $order_status ); ?> {
		    background: #e28077;
		    color: #777;
		}
	    </style>
	    <?php
	}
	

	function cw_add_order_uuid_column_header($columns)
	{
	    $new_columns = array();
	    foreach ($columns as $column_name => $column_info) {
		$new_columns[$column_name] = $column_info;
		if ('order_status' === $column_name) {
		    $new_columns['order_uuid'] = __('UUID', 'woo-uuid');
		}
	    }
	    return $new_columns;
	}
	add_filter('manage_edit-shop_order_columns', 'cw_add_order_uuid_column_header');


	function cw_add_order_uuid_column_content( $column ) {
	    global $post;
	    if ( 'order_uuid' === $column ) {
		$order    = wc_get_order( $post->ID );
		$id = $order->get_id();
		$uuid = get_post_meta($id, 'uuid', true);
		echo ! empty( $uuid ) ? $uuid : '&ndash;';
	    }
	}
	add_action( 'manage_shop_order_posts_custom_column', 'cw_add_order_uuid_column_content' );

	// Display under the admin section
	add_action( 'woocommerce_admin_order_data_after_order_details', 'printuuid_checkout_field_display_admin_order_meta', 10, 1 );

	function printuuid_checkout_field_display_admin_order_meta($order){
        $id = $order->get_id();
		$uuid = get_post_meta( $id, 'uuid', true );
		if(!empty($uuid)){
			echo '<p class="form-field">'.__('UUID','woo-uuid' ).': ' . $uuid . '</p>';
		}
	}

	//Save fields after checkout
	//add_action( 'woocommerce_checkout_update_order_meta', 'printuuid_checkout_field_update_order_meta' );
	function printuuid_checkout_field_update_order_meta( $order_id ) {
			//if ( ! empty( $_POST['uuid'] ) ) {
			update_post_meta( $order_id, 'uuid', sanitize_text_field( $_POST['uuid']));
			//}
	}

	add_action( 'woocommerce_thankyou', 'printuuid_add_content_thankyou',10,1 );
	 
	function printuuid_add_content_thankyou($order_id) {
		$uuid = get_post_meta( $order_id, 'uuid', true );
		$opID = false;
		if(!empty($uuid)){		
			echo '<p>'.__('UUID','woo-uuid').': ' . $uuid . '</p>'; 
			$opID = get_post_meta( $order_id, 'opID', true );

		}

		sleep(1);
		$order = new WC_Order($order_id);
	
		if(!empty($opID)){
			$order->update_status('waitinger', 'order_note'); 	
		}else{		
                	//$order->update_status('printeduuid', 'order_note'); 	
		}
		
	}

	//add uuid in e-mail
	add_filter( 'woocommerce_email_order_meta_fields', 'printuuid_woocommerce_email_order_meta_fields', 10, 3 );

	function printuuid_woocommerce_email_order_meta_fields( $fields, $sent_to_admin, $order ) {
        $id = $order->get_id();
        $uuid =  get_post_meta( $id, 'uuid', true );
	    
		if(!empty($uuid)){
		    $fields['meta_key'] = array(
			'label' => __( 'UUID','woo-uuid' ),
			'value' => get_post_meta( $id, 'uuid', true ),
		    );
		    return $fields;
		}
	    	
	}
//waitingER - waiting for an electronic receipt

    function register_waitinger_order_status() {

	    register_post_status( 'wc-waitinger', array(
		'label'                     => __('waitingER','woo-uuid'),
		'public'                    => true,
		'exclude_from_search'       => false,
		'show_in_admin_all_list'    => true,
		'show_in_admin_status_list' => true,
		'label_count'               => _n_noop( 'waitingER <span class="count">(%s)</span>', 'waitingER <span class="count">(%s)</span>' )
	    ) );
	}
	add_action( 'init', 'register_waitinger_order_status' );
	// Add to list of WC Order statuses
	function add_waitinger_to_order_statuses( $order_statuses ) {

	    $new_order_statuses = array();
	    // add new order status after processing
	    foreach ( $order_statuses as $key => $status ) {
		$new_order_statuses[ $key ] = $status;
		if ( 'wc-processing' === $key ) {
		    $new_order_statuses['wc-waitinger'] = 'waitingER';
		}
	    }
	    return $new_order_statuses;
	}

	add_filter( 'wc_order_statuses', 'add_waitinger_to_order_statuses' );

	add_action('admin_head', 'styling_admin_waitinger_order_list' );
	function styling_admin_waitinger_order_list() {
	    global $pagenow, $post;

	    if( $pagenow != 'edit.php') return; // Exit
	    if( get_post_type($post->ID) != 'shop_order' ) return; // Exit

	    
	    $order_status = 'waitinger'; 
	    ?>
	    <style>
		.order-status.status-<?php echo sanitize_title( $order_status ); ?> {
		    background: #e5e5e5;
		    color: #777;
		}
	    </style>
	    <?php
	}
	

	

	

	
