<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
if ( ! class_exists( 'WC_Email' ) ) {
	return;
}
/**
 * Class WC_Customer_Cancel_Order
 */
class WC_ElectronicData_Order_Email extends WC_Email {

public function __construct() {
	
		$this->id          = 'wc_customer_printed_electronic_receipt';
		$this->title       = __( 'Electronic receipt', 'woo-uuid' );
		$this->description = __( 'An email sent to the customer when an order printed with electronic receipt.', 'woo-uuid' );
    
		$this->customer_email = true;
		$this->heading     = __( 'Electronic receipt', 'woo-uuid' );
		$this->subject     = sprintf( _x( 'Electronic receipt', 'default email subject for cancelled emails sent to the customer', 'woo-uuid' ));
    
    // Template paths.
		$this->template_html  = 'emails/customer-invoice.php';
		$this->template_plain = 'emails/plain/wc-customer-cancelled-order.php';
		$this->template_base  = CUSTOM_WC_EMAIL_PATH . 'templates/';
    
    // Action to which we hook onto to send the email.
		add_action( 'woocommerce_order_status_waitinger_to_printedUUID_notification', array( $this, 'trigger' ) );
                add_action( 'woocommerce_order_status_processing_to_printeduuid_notification',  array( $this, 'trigger' ) );

        	parent::__construct();

		// this sets the recipient to the settings defined below in init_form_fields()
		$this->recipient = $this->get_option( 'recipient' );

		// if none was entered, just use the WP admin email as a fallback
		if ( ! $this->recipient )
		    $this->recipient = get_option( 'admin_email' );
	}
      
        public function trigger( $order_id ) {
		$this->object = wc_get_order( $order_id );
		if ( version_compare( '3.0.0', WC()->version, '>' ) ) {
			$order_email = $this->object->billing_email;
		} else {
			$order_email = $this->object->get_billing_email();
		}
		$this->recipient = $order_email;
		if ( ! $this->is_enabled() || ! $this->get_recipient() ) {
			return;
		}
				
		$this->send( $this->get_recipient(), $this->get_subject(), $this->get_content(), $this->get_headers(), $this->get_attachments() );
	}

	public function get_content_html() {
	
		return wc_get_template_html( $this->template_html, array(
			'order'         => $this->object,
			'email_heading' => $this->get_heading(),
			'sent_to_admin' => false,
			'plain_text'    => false,
			'email'			=> $this
		),'', $this->template_base );
	}

	public function get_content_plain() {

		return wc_get_template_html( $this->template_plain, array(
			'order'         => $this->object,
			'email_heading' => $this->get_heading(),
			'sent_to_admin' => false,
			'plain_text'    => true,
			'email'			=> $this
		), '', $this->template_base );
	}
}


