<?php

function icash_get_account_fields() {
    $user = wp_get_current_user();
    if(is_object($user))
        $companyEIC = esc_attr( get_user_meta($user->ID, 'companyEIC', true ) );
    else
        $companyEIC = null;
	return apply_filters( 'icash_account_fields', array(
		'companyEIC' => array(
			'type'        => 'text',
			'label'       => __('Company EIC', 'woo-uuid'),
			'placeholder' => _x( $companyEIC, 'placeholder', 'woo-uuid'),
			'default'     => $companyEIC,
			'required'    => false,
			'hide_in_account'      => false,
			'hide_in_admin'        => false,
			'hide_in_checkout'     => false,
			'hide_in_registration' => false,
			'class' => array('regular-text'),
		),
	) );
}

function custom_user_profile_fields($user){
    $fields = icash_get_account_fields();
    ?>
    <h3>Extra profile information</h3>
    <table class="form-table">
        <?php foreach ( $fields as $key => $field_args ) { ?>
			<?php
			if ( ! empty( $field_args['hide_in_admin'] ) ) {
				continue;
			}
			?>
			<tr>
				<th>
					<label for="<?php echo $key; ?>"><?php echo $field_args['label']; ?></label>
				</th>
				<td>
					<?php $field_args['label'] = false; ?>
					<?php woocommerce_form_field( $key, $field_args ); ?>
				</td>
			</tr>
		<?php } ?>
    </table>
<?php
}

add_action( 'show_user_profile', 'custom_user_profile_fields' );
add_action( 'edit_user_profile', 'custom_user_profile_fields' );
add_action( "user_new_form", "custom_user_profile_fields" );


function save_custom_user_profile_fields($user_id){

    if(!current_user_can('manage_options'))
        return false; 
    if(isset($_POST['companyEIC'])) {
    	update_user_meta($user_id, 'companyEIC', sanitize_text_field( $_POST['companyEIC']));
	}
}

add_action('user_register', 'save_custom_user_profile_fields');
add_action('profile_update', 'save_custom_user_profile_fields');

function icаsh_print_user_frontend_fields() {
	$fields            = icash_get_account_fields();
	$is_user_logged_in = is_user_logged_in();

	foreach ( $fields as $key => $field_args ) {
		if ( $is_user_logged_in && ! empty( $field_args['hide_in_account'] ) ) {
			continue;
		}

		if ( ! $is_user_logged_in && ! empty( $field_args['hide_in_registration'] ) ) {
			continue;
		}

		woocommerce_form_field( $key, $field_args );
	}
}
add_action( 'woocommerce_edit_account_form' , 'icаsh_print_user_frontend_fields' );

function icash_is_field_visible( $field_args ) {
	$visible = true;
	$action = filter_input( INPUT_POST, 'action' );

	if ( is_admin() && ! empty( $field_args['hide_in_admin'] ) ) {
		$visible = false;
	} elseif ( ( is_account_page() || $action === 'save_account_details' ) && is_user_logged_in() && ! empty( $field_args['hide_in_account'] ) ) {
		$visible = false;
	} elseif ( ( is_account_page() || $action === 'save_account_details' ) && ! is_user_logged_in() && ! empty( $field_args['hide_in_registration'] ) ) {
		$visible = false;
	} elseif ( is_checkout() && ! empty( $field_args['hide_in_checkout'] ) ) {
		$visible = false;
	}

	return $visible;
}

function icash_is_userdata( $key ) {
	$userdata = array(
		'user_pass',
		'user_login',
		'user_nicename',
		'user_url',
		'user_email',
		'display_name',
		'nickname',
		'first_name',
		'last_name',
		'description',
		'rich_editing',
		'user_registered',
		'role',
		'jabber',
		'aim',
		'yim',
		'show_admin_bar_front',
		'companyEIC'
	);

	return in_array( $key, $userdata );
}

function icash_save_account_fields( $customer_id ) {
	$fields = icash_get_account_fields();
	$sanitized_data = array();

	foreach ( $fields as $key => $field_args ) {
		if ( ! icash_is_field_visible( $field_args ) ) {
			continue;
		}

		$sanitize = isset( $field_args['sanitize'] ) ? $field_args['sanitize'] : 'wc_clean';
		$value    = isset( $_POST[ $key ] ) ? call_user_func( $sanitize, $_POST[ $key ] ) : '';

		if ( icash_is_userdata( $key ) ) {
			$sanitized_data[ $key ] = $value;
			continue;
		}		

		update_user_meta( $customer_id, $key, $value );
	}

	if ( ! empty( $sanitized_data ) ) {
		$sanitized_data['ID'] = $customer_id;
		wp_update_user( $sanitized_data );
	}
}

add_action( 'woocommerce_save_account_details', 'icash_save_account_fields' );
add_action( 'woocommerce_created_customer', 'icash_save_account_fields' ); 
add_action( 'personal_options_update', 'icash_save_account_fields' ); 
add_action( 'edit_user_profile_update', 'icash_save_account_fields' ); 
add_action( 'woocommerce_checkout_create_order', 'icash_save_account_fields' ); 
add_action( 'woocommerce_after_order_object_save', 'icash_save_account_fields' ); 

  
function icash_add_custom_checkout_field( $checkout ) { 
    $fields            = icash_get_account_fields();
	$is_user_logged_in = is_user_logged_in();

	foreach ( $fields as $key => $field_args ) {
		if ( $is_user_logged_in && ! empty( $field_args['hide_in_checkout'] ) ) {
			continue;
		}
		
    woocommerce_form_field( $key, $field_args );
	}
}
add_action( 'woocommerce_before_checkout_billing_form', 'icash_add_custom_checkout_field' );
add_action (
    'save_post_shop_order',
    function (int $postId, \WP_Post $post, bool $update): void
    {
		$order_id =$post->ID;
		if ( isset($_POST['companyEIC']) && $_POST['companyEIC'] ) update_post_meta( $order_id, '_billing_companyEIC', esc_attr( $_POST['companyEIC'] ) );

    },
    10,
    3
);
  
function icash_save_new_checkout_field( $order_id ) { 
    if ( $_POST['companyEIC'] ) update_post_meta( $order_id, '_billing_companyEIC', esc_attr( $_POST['companyEIC'] ) );
}

add_action( 'woocommerce_checkout_update_order_meta', 'icash_save_new_checkout_field' );
   
function icash_show_new_checkout_field_order( $order ) {    
   	$order_id = $order->get_id();
	$eic = '';
	
   	if ( get_post_meta( $order_id, '_billing_companyEIC', true ) ) { 
	   $eic = get_post_meta( $order_id, '_billing_companyEIC', true );	   
   	}
	
	echo '<p class="form-field _eic "><label for="eic">'.__("Company EIC", "woo-uuid").'</label><input type="text" class="short" name="companyEIC" id="companyEIC" value='.$eic.'></p>';
}

add_action( 'woocommerce_admin_order_data_after_billing_address', 'icash_show_new_checkout_field_order', 10, 1 );

  
function icash_show_new_checkout_field_emails( $order, $sent_to_admin, $plain_text, $email ) {
    if ( get_post_meta( $order->get_id(), '_billing_companyEIC', true ) ) echo '<p><strong>'.__("Company EIC", "woo-uuid").':</strong> ' . get_post_meta( $order->get_id(), '_billing_companyEIC', true ) . '</p>';
}

add_action( 'woocommerce_email_after_order_table', 'icash_show_new_checkout_field_emails', 20, 4 );



