<?php
/**
 * WooCommerce UUID Test Plugin WC_Settings_Tab_Icash Class
 *
 * @author   d.stanisheva
 * @package  woo-uuid
 * @since    1.0.0
 */


	class WC_Settings_Tab_Icash {

	    public static function init() {
            add_filter( 'woocommerce_settings_tabs_array', __CLASS__ . '::add_settings_tab', 50 );
            add_action( 'woocommerce_settings_tabs_settings_tab_icash', __CLASS__ . '::settings_tab' );
            add_action( 'woocommerce_update_options_settings_tab_icash', __CLASS__ . '::update_settings' );		
                
            add_filter( 'woocommerce_settings_groups', function( $locations ) {
                $locations[] = array(
                    'id'          => 'icash',
                    'label'       => __( 'ICASH Extension', 'woo-uuid' ),
                    'description' => __( 'These are ICASH settings.', 'woo-uuid' ),
                );
                return $locations;
            } );

            add_filter( 'woocommerce_settings-icash', function( $settings ) {
                $settings = self::get_settings();
                return $settings;
            } );

	    }


	    /**
	     * Add a new settings tab to the WooCommerce settings tabs array.
	     *
	     * @param array $settings_tabs Array of WooCommerce setting tabs & their labels, excluding the Subscription tab.
	     * @return array $settings_tabs Array of WooCommerce setting tabs & their labels, including the Subscription tab.
	     */
	    public static function add_settings_tab( $settings_tabs ) {
		$settings_tabs['settings_tab_icash'] = __( 'ICASH', 'woo-uuid' );
		return $settings_tabs;
	    }
	    /**
	     * Uses the WooCommerce admin fields API to output settings via the @see woocommerce_admin_fields() function.
	     *
	     * @uses woocommerce_admin_fields()
	     * @uses self::get_settings()
	     */
	    public static function settings_tab() {
            woocommerce_admin_fields( self::get_settings() );
	    }
	    /**
	     * Uses the WooCommerce options API to save settings via the @see woocommerce_update_options() function.
	     *
	     * @uses woocommerce_update_options()
	     * @uses self::get_settings()
	     */
	    public static function update_settings() {
            woocommerce_update_options( self::get_settings() );
	    }


	    /**
	     * Get all the settings for this plugin for @see woocommerce_admin_fields() function.
	     *
	     * @return array Array of settings for @see woocommerce_admin_fields() function.
	     */
	    public static function get_settings() {

            $settings[] = array( 'name' => __( 'Icash settings', 'woo-uuid' ), 
                        'type' => 'title', 
                        'desc' => __( 'The following options are to configure yours warehause in ICASH/V5', 'woo-uuid' ),
                        'id' => 'wcslider' );


            $readonly = array('readonly' => 'readonly');
			$settings[] = array(
			    'name'     => __( 'Domain', 'woo-uuid' ),
			    'desc_tip' => __( 'Choice the domain!', 'woo-uuid' ),
			    'id'       => 'domain',
			    'option_key'  => 'domain',
 			    'default'  => '',
			    'type'     => 'select',
			    'options' => array(
       					 'v5.icash.bg' 		=> 'v5',
        				 'e-sklad.bg' 		=> 'e-sklad',
                         'app.icash.bg' 	=> 'app.icash.bg',
                         'ibusiness.vivacom.bg' => 'vivacom',
                         'nap.dev.icash.bg' 	=> 'test'
					 ),
			);

            $settings[] = array(
                'name'          => __( 'WareHouse', 'woo-uuid' ),
                'desc_tip'      => __( 'Enter the number of your warehouse!', 'woo-uuid' ),
                'id'            => 'warehouseid',
                'option_key'    => 'warehouseid',	
                'default'       => '',
                'type'          => 'number',
                'custom_attributes' => $readonly,
                'css'           => 'width: 100px'
			);

			$settings[] = array(
			    'name'     => __( 'Work_with_cashregister', 'woo-uuid' ),
			    'desc_tip' => __( 'Enter the number of you work with cashregister!', 'woo-uuid' ),
			    'id'       => 'work_with_cashregister',
			    'option_key'  => 'work_with_cashregister',	
			    'default'  => '',
			    'type'     => 'number',
				'custom_attributes' => $readonly,
				'css'      => 'width: 60px'
			);
			
			$settings[] = array(
			    'name'     => __( 'OnlineStoreID', 'woo-uuid' ),
			    'desc_tip' => __( 'Enter the number of you storeID!', 'woo-uuid' ),
			    'id'       => 'onlineStoreID',
			    'option_key'  => 'onlineStoreID',	
			    'default'  => '',
			    'type'     => 'number',
                'custom_attributes' => $readonly,
				'css'      => 'width: 60px'
		
			);
			
			$settings[] = array(
			    'name'     => __( 'checkIcash', 'woo-uuid' ),
			    'desc_tip' => __( 'checkIcash!', 'woo-uuid' ),
			    'id'       => 'checkIcash',
			    'option_key'  => 'checkIcash',	
			    'default'  => '',
			    'type'     => 'button',                
				'css'      => 'width: 60px',
				'onclick' => '#'
		
			);
			
			$settings[] = array( 'type' => 'sectionend', 'id' => 'settings_tab_icash' );			
     			return apply_filters( 'wc_settings_tab_icash_settings', $settings );
	    }
	}

	WC_Settings_Tab_ICASH::init();


